@@ -14,7 +14,8 @@ __PACKAGE__->mk_accessors qw/
     validator
     readable writable
     length
-    null
+    mandatory
+    distinct 
     refers_to by
     alias_for_column
     since until
