@@ -1,7 +1,8 @@
 package Jifty::DBI::Schema;
+use Carp qw/carp/;
 use Exporter::Lite;
 our @EXPORT
-    = qw(column type default validator immutable unreadable length not_null valid_values label hints render_as since input_filters output_filters mandatory is by are on);
+    = qw(column type default validator immutable unreadable length distinct mandatory not_null valid_values label hints render_as since input_filters output_filters is by are on);
 
 our $SCHEMA;
 
@@ -16,7 +17,6 @@ sub column {
         name     => $name,
         readable => 1,
         writable => 1,
-        null     => 1,
         @_,
     );
     my @original = @args;
@@ -77,8 +77,17 @@ sub length ($) {
     return ( length => shift );
 }
 
+sub mandatory () {
+    return ( [ mandatory => 1 ] );
+}
+
+sub distinct () {
+    return ( [ distinct => 1 ] );
+}
+
 sub not_null () {
-    return ( [ null => 0 ] );
+    carp "'is not_null' is deprecated in favor of 'is mandatory'";
+    return ( [ mandatory => 1 ] );
 }
 
 sub input_filters ($) {
@@ -93,10 +102,6 @@ sub since ($) {
     return ( since => shift );
 }
 
-sub mandatory () {
-    return ( [ mandatory => 1 ] );
-}
-
 sub valid_values ($) {
     return ( valid_values => shift );
 }
@@ -115,7 +120,7 @@ sub render_as ($) {
 
 sub is ($) {
     my $thing = shift;
-    return ref $thing ? @{$thing} : $thing;
+    return ref $thing eq "ARRAY" ? @{$thing} : $thing;
 }
 
 sub by ($) {
